# qwertypy

My personal utilities library.

## Resources

### Setup and configurations

1. https://medium.com/vlmedia-tech/step-by-step-guide-to-create-python-library-using-ci-cd-pipeline-8e66022108df
2. https://keepachangelog.com/
